==> nextcloud-22.2.10.tgz: nextcloud/apps/activity/l10n/es_SV.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "Home" : "Inicio",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "Mail" : "Correo",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "No activity yet" : "Aún no tiene actividad",
    "Activities" : "Actividades",
    "No activities" : "No hay actividades",
    "Activity feed" : "Fuente de actividad",
    "Default settings" : "Configuraciones predeterminadas",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Settings" : "Configuraciones ",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "No more events to load" : "No hay más eventos por cargar",
    "Activity notification for %s" : "Notificación de actividad para %s"
},
"nplurals=2; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-23.0.8.tgz: nextcloud/apps/activity/l10n/es_SV.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "Home" : "Inicio",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "Mail" : "Correo",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "No activity yet" : "Aún no tiene actividad",
    "Activities" : "Actividades",
    "No activities" : "No hay actividades",
    "Activity feed" : "Fuente de actividad",
    "Default settings" : "Configuraciones predeterminadas",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "No more events to load" : "No hay más eventos por cargar",
    "Activity notification for %s" : "Notificación de actividad para %s",
    "Settings" : "Configuraciones "
},
"nplurals=2; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
